# Change Log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## [0.2.0-RC1] - CAPTCHA Solving
### Added
- `Solve` module with support for OCR, online and manual solving
- Supports Solve Media

## [0.1.3] - Action Chains
### Added
- Function `action()`

## [0.1.2] - Proxies
### Added
- Optional parameter `proxy` for connecting through a proxy

## [0.1.1] - Handle timeout
### Added
- Function `get(url)`

## [0.1.0] - Selenium
### Added
- Web module
- Browser class
-  Example in README

[0.2.0-RC1]: https://bitbucket.org/bkvaluemeal/caboodle/issues/5/captcha-solving
[0.1.3]: https://bitbucket.org/bkvaluemeal/caboodle/issues/4/action-chains
[0.1.2]: https://bitbucket.org/bkvaluemeal/caboodle/issues/3/proxies
[0.1.1]: https://bitbucket.org/bkvaluemeal/caboodle/issues/2/handle-timeout
[0.1.0]: https://bitbucket.org/bkvaluemeal/caboodle/issues/1/selenium
